@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.073';
+$VERSION = '2.074';
 use base 'Mail::Reporter';
 
 use Mail::Message::Part;
@@ -67,8 +67,6 @@ sub init($)
     $self;
 }
 
-#------------------------------------------
-
 
 sub clone(@)
 {   my ($self, %args) = @_;
@@ -108,28 +106,18 @@ sub clone(@)
 sub messageId() { $_[0]->{MM_message_id} || $_[0]->takeMessageId}
 sub messageID() {shift->messageId}   # compatibility
 
-#------------------------------------------
-
 
 sub container() { undef } # overridden by Mail::Message::Part
 
-#------------------------------------------
-
 
 sub isPart() { 0 } # overridden by Mail::Message::Part
 
-#------------------------------------------
-
 
 sub toplevel() { shift } # overridden by Mail::Message::Part
 
-#------------------------------------------
-
 
 sub isDummy() { 0 }
 
-#------------------------------------------
-
 
 sub print(;$)
 {   my $self = shift;
@@ -140,8 +128,6 @@ sub print(;$)
     $self;
 }
 
-#------------------------------------------
-
 
 sub write(;$)
 {   my $self = shift;
@@ -152,8 +138,6 @@ sub write(;$)
     $self;
 }
 
-#------------------------------------------
-
 
 my $default_mailer;
 
@@ -178,8 +162,6 @@ sub send(@)
     $mailer->send($self, %args);
 }
 
-#------------------------------------------
-
 
 sub size()
 {   my $self = shift;
@@ -215,8 +197,6 @@ sub head(;$)
     $head;
 }
 
-#------------------------------------------
-
 
 sub get($)
 {   my $self  = shift;
@@ -224,24 +204,18 @@ sub get($)
     $field->body;
 }
 
-#------------------------------------------
-
 
 sub study($)
 {  my $head = shift->head or return;
    scalar $head->study(@_);    # return only last
 }
 
-#-------------------------------------------
-
 
 sub from()
 {  my $from = shift->head->get('From') or return ();
    map {$_->addresses} $from;
 }
 
-#-------------------------------------------
-
 
 sub sender()
 {   my $self   = shift;
@@ -251,25 +225,15 @@ sub sender()
     ($sender->addresses)[0];                 # first specified address
 }
 
-#-------------------------------------------
-
 
 sub to() { map {$_->addresses} shift->head->get('To') }
 
-#-------------------------------------------
-
 
 sub cc() { map {$_->addresses} shift->head->get('Cc') }
 
-#-------------------------------------------
-
 
 sub bcc() { map {$_->addresses} shift->head->get('Bcc') }
 
-#-------------------------------------------
-
-
-#-------------------------------------------
 
 
 sub destinations()
@@ -279,29 +243,21 @@ sub destinations()
     values %to;
 }
 
-#-------------------------------------------
-
 
 sub subject()
 {   my $subject = shift->get('subject');
     defined $subject ? $subject : '';
 }
 
-#-------------------------------------------
-
 
 sub guessTimestamp() {shift->head->guessTimestamp}
 
-#-------------------------------------------
-
 
 sub timestamp()
 {   my $head = shift->head;
     $head->recvstamp || $head->timestamp;
 }
 
-#------------------------------------------
-
 
 sub nrLines()
 {   my $self = shift;
@@ -344,8 +300,6 @@ sub body(;$@)
     $self->{MM_body} = $body;
 }
 
-#------------------------------------------
-
 
 sub decoded(@)
 {   my ($self, %args) = @_;
@@ -359,26 +313,18 @@ sub decoded(@)
     $decoded;
 }
 
-#------------------------------------------
-
 
 sub encode(@)
 {   my $body = shift->body->load;
     $body ? $body->encode(@_) : undef;
 }
 
-#-------------------------------------------
-
 
 sub isMultipart() {shift->head->isMultipart}
 
-#-------------------------------------------
-
 
 sub isNested() {shift->body->isNested}
 
-#-------------------------------------------
-
 
 sub parts(;$)
 {   my $self    = shift;
@@ -418,8 +364,6 @@ sub modified(;$)
     $flag;
 }
 
-#------------------------------------------
-
 
 sub isModified()
 {   my $self = shift;
@@ -440,8 +384,6 @@ sub isModified()
     0;
 }
 
-#------------------------------------------
-
 
 sub label($;$@)
 {   my $self   = shift;
@@ -453,21 +395,15 @@ sub label($;$@)
     $return;
 }
 
-#------------------------------------------
-
 
 sub labels()
 {   my $self = shift;
     wantarray ? keys %{$self->{MM_labels}} : $self->{MM_labels};
 }
 
-#------------------------------------------
-
 
 sub isDeleted() { shift->label('deleted') }
 
-#-------------------------------------------
-
 
 sub delete()
 {  my $self = shift;
@@ -475,8 +411,6 @@ sub delete()
    $old || $self->label(deleted => time);
 }
 
-#-------------------------------------------
-
 
 sub deleted(;$)
 {   my $self = shift;
@@ -485,8 +419,6 @@ sub deleted(;$)
        : $self->label('deleted')   # compat 2.036
 }
 
-#-------------------------------------------
-
 
 sub labelsToStatus()
 {   my $self    = shift;
@@ -513,8 +445,6 @@ sub labelsToStatus()
     $self;
 }
 
-#-------------------------------------------
-
 
 sub statusToLabels()
 {   my $self    = shift;
@@ -542,9 +472,6 @@ sub statusToLabels()
 #------------------------------------------
 
 
-#------------------------------------------
-
-
 my $mail_internet_converter;
 my $mime_entity_converter;
 my $email_simple_converter;
@@ -579,6 +506,7 @@ sub coerce($@)
         $message = $mail_internet_converter->from($message)
             or return;
     }
+
     elsif($message->isa('Email::Simple'))
     {   unless($email_simple_converter)
         {   eval {require Mail::Message::Convert::EmailSimple};
@@ -603,8 +531,6 @@ sub coerce($@)
     bless $message, $class;
 }
 
-#------------------------------------------
-
 
 sub clonedFrom() { shift->{MM_cloned} }
 
@@ -613,8 +539,6 @@ sub clonedFrom() { shift->{MM_cloned} }
 sub isParsed()   { not shift->isDelayed }
 sub headIsRead() { not shift->head->isa('Mail::Message::Delayed') }
 
-#------------------------------------------
-
 
 sub readFromParser($;$)
 {   my ($self, $parser, $bodytype) = @_;
@@ -634,8 +558,6 @@ sub readFromParser($;$)
     $self;
 }
 
-#------------------------------------------
-
 
 sub readHead($;$)
 {   my ($self, $parser) = (shift, shift);
@@ -650,8 +572,6 @@ sub readHead($;$)
       )->read($parser);
 }
 
-#------------------------------------------
-
 
 my $mpbody = 'Mail::Message::Body::Multipart';
 my $nbody  = 'Mail::Message::Body::Nested';
@@ -673,7 +593,7 @@ sub readBody($$;$$)
           );
     }
     else
-    {   my $ct   = $head->get('Content-Type');
+    {   my $ct   = $head->get('Content-Type', 0);
         my $type = defined $ct ? lc($ct->body) : 'text/plain';
 
         # Be sure you have acceptable bodies for multiparts and nested.
@@ -700,8 +620,6 @@ sub readBody($$;$$)
       );
 }
 
-#------------------------------------------
-
 
 sub storeBody($)
 {   my ($self, $body) = @_;
@@ -710,16 +628,12 @@ sub storeBody($)
     $body;
 }
 
-#-------------------------------------------
-
 
 sub isDelayed()
 {    my $body = shift->body;
      !$body || $body->isDelayed;
 }
 
-#------------------------------------------
-
 
 sub takeMessageId(;$)
 {   my $self  = shift;
@@ -752,8 +666,6 @@ sub shortSize(;$)
     :                      sprintf "%3.0fM", $size/(1024*1024);
 }
 
-#------------------------------------------
-
 
 sub shortString()
 {   my $self    = shift;
@@ -772,8 +684,6 @@ sub DESTROY()
     $self->body(undef);
 }
 
-#------------------------------------------
-
 
 sub destruct() { $_[0] = undef }
 
