@@ -13,7 +13,7 @@ use Tools;             # test tools
 use Mail::Reporter;    # to avoid 'too late for INIT'
 
 use IO::Dir;
-use Test::Harness qw($verbose);
+use Test::Harness qw($verbose execute_tests);
 
 # we use Test::More without a plan here, but we don't want
 # Test::Builder to mess with the exit code
@@ -43,7 +43,9 @@ my @show_versions = defined $select_tests ? ()
       Test::Harness Encode
      /;
 
-my $skip_tests = -f 'skiptests';
+my $skip_tests = ($ENV{MAILBOX_RUN_TESTS} || 'yes') eq 'no'
+              || -f 'skiptests' || -f '../skiptests';
+
 sub package_of($);
 sub testnames($);
 sub run_in_harness(@);
@@ -59,7 +61,8 @@ WARN
 if($skip_tests)
 {   warn <<'WARN';
 * Tests are disabled, because you said so when the Makefile was created.
-* remove the file "skiptests" if you want to run them.
+* remove the file "skiptests" if you want to run them and/or clear
+* environment variable MAILBOX_RUN_TESTS
 *
 WARN
     exit 0;
@@ -183,7 +186,10 @@ sub run_in_harness(@)
 {   my @files = @_;
     return 1 unless @files;
 
-    my ($tot, $failed) = Test::Harness::_run_all_tests(@files);
+    # lib::cached experiments, work around bug in Test::Harness::Straps.
+    shift @INC if ref $INC[0] eq 'CODE';
+
+    my ($tot,$failed) = execute_tests(tests => \@files);
     Test::Harness::_all_ok($tot);
 }
 
