@@ -6,12 +6,9 @@
 use strict;
 package Tools;
 use vars '$VERSION';
-$VERSION = '2.073';
-
-#use lib qw(. ./lib ../lib ../../lib tests);
-#use lib qw(/home/markov/shared/perl/UserIdentity/lib);
-#use lib qw(/home/markov/shared/perl/MimeTypes/lib);
+$VERSION = '2.074';
 
+use lib qw(lib ../lib);
 use base 'Exporter';
 use File::Copy 'copy';
 use List::Util 'first';
